####################################################################################################### 
#                                                                                                     #
#  FFFFFFFFFFFF  RRRRRRRRRRR  EEEEEEEEEEE  AAAAAAAAAAAAAAA  KK      KK  YY        YY  YY        YY    #
#  FFFFFFFFFFFF  RRRRRRRRRRR  EEEEEEEEEEE  AAAAAAAAAAAAAAA  KK    KK     YY      YY    YY      YY     #
#  FF            RR       RR  EE           AA           AA  KK   KK       YY    YY      YY    YY      #
#  FF            RR       RR  EE           AA           AA  KK KK          YY  YY        YY  YY       #
#  FFFFFFFFFFFF  RRRRRRRRRRR  EEEEEEEEEEE  AAAAAAAAAAAAAAA  KKKK            YYYY          YYYY        #
#  FFFFFFFFFFFF  RRRRR        EEEEEEEEEEE  AAAAAAAAAAAAAAA  KK KK            YY            YY         #
#  FF            RR  RR       EE           AA           AA  KK   KK          YY            YY         #
#  FF            RR    RR     EE           AA           AA  KK    KK         YY            YY         #
#  FF            RR     RR    EEEEEEEEEEE  AA           AA  KK     KK        YY            YY         #
#  FF            RR      RR   EEEEEEEEEEE  AA           AA  KK      KK       YY            YY         #
#                                                                                                     #
#######################################################################################################

#
# COOLTIMELIB PY
#      VERSION 1.0
#
# Copyright (c)
#           2012
#
# By Freakyy / Jan S.
# Contact:
#    - Steam: fre4kpwned

# =============================================================================
# >> IMPORTS
# =============================================================================
import es
import cmdlib
import gamethread

# =============================================================================
# >> LOG
# =============================================================================

def log(m):
    es.dbgmsg(0,m)
    es.log(m)

# =============================================================================
# >> COOLTIME-LIB
# =============================================================================
class CoolTimeObject(object):
     # > Init
     def __init__(self):
         self.global_cool = []
         self.user_cool   = {}
         
     # > USER
     def canUser(self, userid, name):
         if not name in self.user_cool:
            return True
         if userid in self.user_cool[name]:
            return False
         return True
         
     def appendUser(self, userid, name, seconds):
         if not self.canUser(userid, name):
            log('CoolTime: User %i has already a cooltime in "%s"' % (userid, name))
            return
         if not name in self.user_cool:
            self.user_cool[name] = []
         self.user_cool[name].append(int(userid))
         gamethread.delayed(seconds, self.removeUserCooltime, (userid, name))
         
     def removeUserCooltime(self, userid, name):
         if not self.canUser(userid, name):
            self.user_cool[name].remove(int(userid)) 
         else:
            log('CoolTime: User "%i" in "%s" has no Cool-Time!' % (int(userid), name))
     
     # > GLOBAL
     def can(self, name):
         if not name in self.global_cool:
            return True
         return False
         
     def append(self, name, seconds):
         if not self.can(name):
            log('CoolTime: "%s" is already a running Cool-Time!' % name) 
            return
         self.global_cool.append(name)
         gamethread.delayed(seconds, self.removeCooltime, name)
         
     def removeCooltime(self, name):
         if not self.can(name):
            self.global_cool.remove(name)
         else:
            log('CoolTime: "%s" is not a running Cool-Time!' % name)
        
cooltime = CoolTimeObject()
# =============================================================================
# >> PUBLIC
# =============================================================================
def canUser(userid, name):
    return cooltime.canUser(userid, name)
    
def appendUser(userid, name, seconds):
    return cooltime.appendUser(userid, name, seconds)
    
def removeUserCooltime(userid, name):
    return cooltime.removeUserCooltime(userid, name)
    

def can(name):
    return cooltime.can(name)
    
def append(name, seconds):
    return cooltime.append(name, seconds)
    
def removeCooltime(name):
    return cooltime.removeCooltime(name)
    
# =============================================================================
# >> VARIABLE
# =============================================================================
es.set('cooltimelib_version', '1.0')
es.makepublic('cooltimelib_version')