####################################################################################################### 
#                                                                                                     #
#  FFFFFFFFFFFF  RRRRRRRRRRR  EEEEEEEEEEE  AAAAAAAAAAAAAAA  KK      KK  YY        YY  YY        YY    #
#  FFFFFFFFFFFF  RRRRRRRRRRR  EEEEEEEEEEE  AAAAAAAAAAAAAAA  KK    KK     YY      YY    YY      YY     #
#  FF            RR       RR  EE           AA           AA  KK   KK       YY    YY      YY    YY      #
#  FF            RR       RR  EE           AA           AA  KK KK          YY  YY        YY  YY       #
#  FFFFFFFFFFFF  RRRRRRRRRRR  EEEEEEEEEEE  AAAAAAAAAAAAAAA  KKKK            YYYY          YYYY        #
#  FFFFFFFFFFFF  RRRRR        EEEEEEEEEEE  AAAAAAAAAAAAAAA  KK KK            YY            YY         #
#  FF            RR  RR       EE           AA           AA  KK   KK          YY            YY         #
#  FF            RR    RR     EE           AA           AA  KK    KK         YY            YY         #
#  FF            RR     RR    EEEEEEEEEEE  AA           AA  KK     KK        YY            YY         #
#  FF            RR      RR   EEEEEEEEEEE  AA           AA  KK      KK       YY            YY         #
#                                                                                                     #
#######################################################################################################

#
# COOLTIMELIB ESS
#      VERSION 1.0
#
# Copyright (c)
#           2012
#
# By Freakyy / Jan S.
# Contact:
#    - Steam: fre4kpwned

# =============================================================================
# >> IMPORTS
# =============================================================================
import es
import cmdlib
import cooltimelib as cooltime
import gamethread

# =============================================================================
# >> LOG
# =============================================================================
def log(m,l=1):
    es.dbgmsg(l,m)
    es.log(m)
    
# =============================================================================
# >> LOAD & UNLOAD
# =============================================================================
def load():
    # > Register commands
    register_commands()
    # > Announce
    log('CoolTime: Loaded!')
    # > Vars
    es.set('cooltimelib_ess_version', '1.0')
    es.makepublic('cooltimelib_ess_version')
    
def unload():
    # > Unregister commands
    unregister_commands()
    # > Announce
    log('CoolTime: Unloaded!')
    
# =============================================================================
# >> COMMAND >> REGISTERS
# =============================================================================
def register_commands():
    cmdlib.registerServerCommand('cooltime', ct_command, 'CoolTime')
    
# =============================================================================
# >> COMMAND >> UNREGISTERS
# =============================================================================
def unregister_commands():
    cmdlib.unregisterServerCommand('cooltime')

# =============================================================================
# >> COMMANDS >> USER
# =============================================================================
def ct_command(args):
    av = 'canuser|appenduser|removeusercooltime|can|append|removecooltime'
    # > Check arg-len
    if len(args) == 0:
       es.dbgmsg(0, av)
       return
    # > Check for command
    cmd = args[0]
    argc= args[1:]
    # > User-Specific
    if cmd == 'canuser':
       ct_canuser(argc)
    elif cmd == 'appenduser':  
       ct_appendUser(argc)
    elif cmd == 'removeusercooltime':
       ct_removeUserCooltime(argc)
    # > Global Cooltimes
    elif cmd == 'can':
       ct_can(argc)
    elif cmd == 'append':
       ct_append(argc)
    elif cmd == 'removecooltime':
       ct_removeCooltime(argc)
    else:
       # > Provided something other
       log('Error! %s is not an avaiable substring of cooltime!' % cmd, 0)
       log('Avaiable: %s' % av, 0)
    
def ct_canuser(args):
    # > Check arg-len
    if len(args) != 3:
       log('Usage: cooltime canuser <var> <userid> <name>', 0)
       return
    # > Args
    var    = args[0]
    userid = args[1]
    name   = args[2]
    # > Check args
    if not es.exists('userid', userid):
       log('CoolTime: %s is not a valid User-ID!' % userid, 0)
       return
    # > Continue
    result = cooltime.canUser(userid, name)
    if result == True:
       result = 1
    else: 
       result = 0
    es.set(var, result)
    
def ct_appendUser(args):
    # > Check arg-len
    if len(args) != 3:
       log('Usage: cooltime appenduser <userid> <name> <seconds>', 0)
       return
    # > Args
    userid = args[0]
    name   = args[1]
    secs   = args[2]
    # > Check args
    if not es.exists('userid', userid):
       log('CoolTime: %s is not a valid User-ID!' % userid, 0)
       return
    try:
       secs = float(secs)
    except ValueError, e:
       es.dbgmsg(0, 'Usage: cooltime append <name> <seconds [Float, not string]>')
       return
    # > Continue
    cooltime.appendUser(userid, name, secs)
    
def ct_removeUserCooltime(args):
    # > Check arg-len
    if len(args) != 2:
       log('Usage: cooltime removeusercooltime <userid> <name>', 0)
       return
    # > Args
    userid = args[0]
    name   = args[1]
    # > Check args
    if not es.exists('userid', userid):
       log('CoolTime: %s is not a valid User-ID!' % userid, 0)
       return
    # > Continue
    cooltime.removeUserCooltime(userid, name)
    
# =============================================================================
# >> COMMANDS >> GLOBALS
# =============================================================================
def ct_can(args):
    # > Check arg-len
    if len(args) != 2:
       log('Usage: cooltime can <var> <name>', 0)
       return
    # > Args
    var    = args[0]
    name   = args[1]
    # > Continue
    result = cooltime.can(name)
    if result == True:
       result = 1
    else: 
       result = 0
    es.set(var, result)
    
def ct_append(args):
    # > Check arg-len
    if len(args) != 2:
       log('Usage: cooltime append <name> <seconds>', 0)
       return
    # > Args
    name   = args[0]
    secs   = args[1]
    # > Check args
    try:
       secs = float(secs)
    except ValueError, e:
       es.dbgmsg(0, 'Usage: cooltime append <name> <seconds [Float, not string]>')
       return
    # > Continue
    cooltime.append(name, secs)
    
def ct_removeCooltime(args):
    # > Check arg-len
    if len(args) != 1:
       es.dbgmsg(0, 'Usage: cooltime removecooltime <name>')
       return
    # > Args
    name = args[0]
    # > Continue
    cooltime.removeCooltime(name)